_: {
  programs.waybar = {
    enable = true;
    systemd.enable = true;

    settings = {
      mainBar = {
        layer = "top";
        position = "top";
        # Choose the order of the modules
        modules-left = ["hyprland/workspaces"];
        modules-center = ["custom/music"];
        modules-right = ["wireplumber" "backlight" "battery" "clock" "tray" "custom/lock" "custom/power"];
        "hyprland/workspaces" = {
          "format" = " {icon} ";
          "format-icons" = {
            "default" = " ";
          };
        };
        tray = {
          "icon-size" = 21;
          "spacing" = 10;
        };
        "custom/music" = {
          format = "  {}";
          escape = true;
          interval = 5;
          tooltip = false;
          exec = "playerctl metadata --format='{{ title }}'";
          on-click = "playerctl play-pause";
          max-length = 50;
        };
        clock = {
          timezone = "America/New_York";
          tooltip-format = "<big>{:%Y %B}</big>\n<tt><small>{calendar}</small></tt>";
          format-alt = "  {:%B %d, %Y}";
          format = "  {:%I:%M %p}";
        };
        backlight = {
          device = "amdgpu_bl1";
          format = "{icon} {percent}%";
          format-icons = [" " " " " " " " " " " " " " " " " "];
        };
        battery = {
          states = {
            warning = 30;
            critical = 15;
          };
          format = "{icon} {capacity}%";
          format-icons = [" " " " " " " " " "];
        };
        wireplumber = {
          format = "{icon} {volume}%";
          format-muted = " ";
          format-icons = {
            default = ["" " " " "];
          };
          on-click = "pavucontrol";
        };
        "custom/lock" = {
          "tooltip" = false;
          "on-click" = "echo lock";
          "format" = " ";
        };
        "custom/power" = {
          "tooltip" = false;
          "on-click" = "echo power";
          "format" = " ";
        };
      };
    };

    style = ''
      * {
        font-family: "FantasqueSansM Nerd Font";
        font-size: 17px;
        min-height: 0;
      }

      #waybar {
        background: transparent;
        color: @text;
        margin: 5px 5px;
      }

      #workspaces {
        border: 2px solid @lavender;
        border-radius: 8px;
        margin: 5px;
        background-color: @base;
        margin-left: 20px;
      }

      #workspaces button {
        color: @lavender;
        border-radius: 8px;
        padding: 0.4rem;
      }

      #workspaces button.active {
        color: @mauve;
        border-radius: 8px;
      }

      #workspaces button:hover {
        color: @pink;
        border-radius: 8px;
      }

      #custom-music,
      #tray,
      #backlight,
      #clock,
      #battery,
      #wireplumber,
      #custom-lock,
      #custom-power {
        border-top: 2px solid @lavender;
        border-bottom: 2px solid @lavender;
        background-color: @base;
        padding: 0.5rem 1rem;
        margin: 5px 0;
      }

      #clock {
        color: @blue;
        border-radius: 0px 8px 8px 0px;
        margin-right: 1rem;
        border-right: 2px solid @lavender;
      }

      #battery {
        color: @green;
      }

      #battery.charging {
        color: @green;
      }

      #battery.warning:not(.charging) {
        color: @red;
      }

      #backlight {
        color: @yellow;
      }

      #backlight, #battery {
          border-radius: 0;
      }

      #wireplumber {
        color: @maroon;
        border-radius: 8px 0px 0px 8px;
        border-left: 2px solid @lavender;
        margin-left: 1rem;
      }

      #custom-music {
        color: @text;
        border-radius: 8px;
        border-left: 2px solid @lavender;
        border-right: 2px solid @lavender;
      }

      #custom-lock {
          border-radius: 8px 0px 0px 8px;
          border-top: 2px solid @lavender;
          border-bottom: 2px solid @lavender;
          border-left: 2px solid @lavender;
          color: @lavender;
      }

      #custom-power {
          margin-right: 20px;
          border-radius: 0px 8px 8px 0px;
          border-top: 2px solid @lavender;
          border-bottom: 2px solid @lavender;
          border-right: 2px solid @lavender;
          color: @lavender;
      }

      #tray {
        margin-right: 1rem;
        border-radius: 8px;
        border-left: 2px solid @lavender;
        border-right: 2px solid @lavender;
      }
    '';
  };
}
